<?php
/*
Plugin Name: WP Pricing Tables
Plugin URI: http://wppricingtables.customizewp.com
Description: Wordpress plugin which will give you the ability of easily adding pricing tables to your site. You can choose from 6 tyles and 16 colors. Additionaly you can add ribbons, tooltips, featured columns and much more.
Version: 1.3.5
Author: CustomizeWP
Author URI: http://customizewp.com
License: Please refer to CodeCanyon.net licence
*/


// Include constants file
require_once( dirname( __FILE__ ) . '/lib/constants.php' );

class WPPricingTables {
    var $namespace = "wpptabs";
    var $friendly_name = "WP Pricing Tables";
    var $version = "1.3.5";
    
    // Default plugin options
    var $defaults = array(
        'option_1' => "foobar"
    );
    
    /**
     * Instantiation construction
     * 
     * @uses add_action()
     * @uses WPPricingTables::wp_register_scripts()
     * @uses WPPricingTables::wp_register_styles()
     */
    function __construct() {
        // Name of the option_value to store plugin options in
        $this->option_name = '_' . $this->namespace . '--options';
		
        // Load all library files used by this plugin
        $libs = glob( WPPTABS_DIRNAME . '/lib/*.php' );
		//  require_once( WPPTABS_DIRNAME . '/css/table_width.php' );
        foreach( $libs as $lib ) {
            include_once( $lib );
        }
        
        /**
         * Make this plugin available for translation.
         * Translations can be added to the /languages/ directory.
         */
        load_theme_textdomain( $this->namespace, WPPTABS_DIRNAME . '/languages' );

		// Add all action, filter and shortcode hooks
		$this->_add_hooks();
    }
    
    /**
     * Add in various hooks
     * 
     * Place all add_action, add_filter, add_shortcode hook-ins here
     */
    private function _add_hooks() {
        // Options page for configuration
        add_action( 'admin_menu', array( &$this, 'admin_menu' ) );
        // Route requests for form processing
        add_action( 'init', array( &$this, 'route' ) );
        
      
        // Register all JavaScripts for this plugin
        add_action( 'init', array( &$this, 'wp_register_scripts' ), 1 );
        // Register all Stylesheets for this plugin
        add_action( 'init', array( &$this, 'wp_register_styles' ), 1 );
    }
    
    /**
     * Process update page form submissions
     * 
     * @uses WPPricingTables::sanitize()
     * @uses wp_redirect()
     * @uses wp_verify_nonce()
     */
    private function _admin_options_update() {
        // Verify submission for processing using wp_nonce
        if( wp_verify_nonce( $_REQUEST['_wpnonce'], "{$this->namespace}-update-options" ) ) {
            $data = array();
            /**
             * Loop through each POSTed value and sanitize it to protect against malicious code. Please
             * note that rich text (or full HTML fields) should not be processed by this function and 
             * dealt with directly.
             */
            foreach( $_POST['data'] as $key => $val ) {
                $data[$key] = $this->_sanitize( $val );
            }
            
            /**
             * Place your options processing and storage code here
             */
            
            // Update the options value with the data submitted
            update_option( $this->option_name, $data );
            
            // Redirect back to the options page with the message flag to show the saved message
            wp_safe_redirect( $_REQUEST['_wp_http_referer'] . '&message=1' );
            exit;
        }
    }
    
    /**
     * Sanitize data
     * 
     * @param mixed $str The data to be sanitized
     * 
     * @uses wp_kses()
     * 
     * @return mixed The sanitized version of the data
     */
    private function _sanitize( $str ) {
        if ( !function_exists( 'wp_kses' ) ) {
            require_once( ABSPATH . 'wp-includes/kses.php' );
        }
        global $allowedposttags;
        global $allowedprotocols;
        
        if ( is_string( $str ) ) {
            $str = wp_kses( $str, $allowedposttags, $allowedprotocols );
        } elseif( is_array( $str ) ) {
            $arr = array();
            foreach( (array) $str as $key => $val ) {
                $arr[$key] = $this->_sanitize( $val );
            }
            $str = $arr;
        }
        
        return $str;
    }
	

    /**
     * Hook into register_activation_hook action
     * 
     * Put code here that needs to happen when your plugin is first activated (database
     * creation, permalink additions, etc.)
     */
     function activate() {
	 
		  delete_option('wpptabs_table_themes');     //add table theme   
	 //Theme for table
        $table_themes_array=array(
        'Theme 1' => 'cwp-wppt-pricing-table_1',
        'Theme 2' => 'cwp-wppt-pricing-table_2',  
        'Theme 3' => 'cwp-wppt-pricing-table_3',
        'Theme 4' => 'cwp-wppt-pricing-table_4',
        'Theme 5' => 'cwp-wppt-pricing-table_5',
        'Theme 6' => 'cwp-wppt-pricing-table_6'   
        );
		
         //Colors for table
        $themes_colors_sets=array('themes_colors_sets'=> array(
		        'black'=>'black',
				'brown'=>'brown',
				'dark blue'=>'dark-blue', 
				'dark green'=>'dark-green',
				'dark purple'=>'dark-purple',
				'grey'=>'grey',
				'ice blue'=>'ice-blue',
				'lime'=>'lime',
				'olive'=>'olive',
				'orange'=>'orange',
				'pink'=>'pink',
				'red'=>'red',
				'turquoise'=>'turquoise',
				'very dark blue'=>'very-dark-blue',
				'white'=>'white',
				'yellow'=>'yellow',
				));
				//Colors for tooltip
				  $tp=array(
		        'black'=>'black',
				'brown'=>'brown',
				'dark blue'=>'dark-blue', 
				'dark green'=>'dark-green',
				'dark purple'=>'dark-purple',
				'grey'=>'grey',
				'ice blue'=>'ice-blue',
				'lime'=>'lime',
				'olive'=>'olive',
				'orange'=>'orange',
				'pink'=>'pink',
				'red'=>'red',
				'turquoise'=>'turquoise',
				'very dark blue'=>'very-dark-blue',
				'white'=>'white',
				'yellow'=>'yellow'
				                     );
									 //Colors for ribbon 
        $ribbon_colors_sets=array(
		        'black'=>'black',
				'brown'=>'brown',
				'dark blue'=>'dark-blue', 
				'dark green'=>'dark-green',
				'dark purple'=>'dark-purple',
				'grey'=>'grey',
				'ice blue'=>'ice-blue',
				'lime'=>'lime',
				'olive'=>'olive',
				'orange'=>'orange',
				'no ribbon'=>'no-ribbon',
				'pink'=>'pink',
				'red'=>'red',
				'turquoise'=>'turquoise',
				'very dark blue'=>'very-dark-blue',
				'white'=>'white',
				'yellow'=>'yellow'
				                     );
									 //size for ribbon
							   $ribbon_size_sets=array(
		        'small'=>'small',
				'big'=>'big'
				
			                    );
								 $time=array(
								 'Year'=>'year',
		        'Month'=>'month',
				'Day'=>'day'
				
			                    );
								//Position for Tooltip
															   $tooltip_position_sets=array(
		        'top'=>'top',
				'left'=>'left',
				'right'=>'right',
				'bottom'=>'bottom',
				'top left'=>'top-left',
				'top right'=>'top-right',
				
				'bottom left'=>'bottom-left',
				'bottom right'=>'bottom-right'
				
			                    );
							   //add option to script
							   add_option('wpptabs_time' , serialize($time)); //add ribbon colors
 
 add_option('wpptabs_ribbon_colors' , serialize($ribbon_colors_sets)); //add ribbon colors
   add_option('wpptabs_ribbon_sizes' , serialize($ribbon_size_sets)); //add ribbon sizes
        add_option('wpptabs_table_themes' , serialize($table_themes_array));     //add table theme   
        add_option('wpptabs_themes_colors' , serialize($themes_colors_sets));    //add table color  
   add_option('wpptabs_tooltip_colors' , serialize($tp));      //add tooltip colors
   add_option('wpptabs_tooltip_position' , serialize($tooltip_position_sets)); //add tooltip position
  add_filter( 'query_vars', 'addnew_query_vars', 10, 1 );
 
function addnew_query_vars($vars )
{   
    $vars[] = 'billing_id' ; // var1 is the name of variable you want to add       
    return $vars;
}

      		
    }
	
    /**
     * Define the admin menu options for this plugin
     * 
     * @uses add_action()
     * @uses add_options_page()
     */
    function admin_menu() {
        $page_hook = add_submenu_page('edit.php?post_type=wpptabs', 'PT Settings', 'PT Settings','','');
        
        // Add print scripts and styles action based off the option page hook
        add_action( 'admin_print_scripts-' . $page_hook, array( &$this, 'admin_print_scripts' ) );
        add_action( 'admin_print_styles-' . $page_hook, array( &$this, 'admin_print_styles' ) );
    }
    
    
    /**
     * The admin section options page rendering method
     * 
     * @uses current_user_can()
     * @uses wp_die()
     */
   
    
    /**
     * Load JavaScript for the admin options page
     * 
     * @uses wp_enqueue_script()
     */
    function admin_print_scripts() {
        //wp_enqueue_script( 'wpptabs-table-modifier' );
    }
    
    /**
     * Load Stylesheet for the admin options page
     * 
     * @uses wp_enqueue_style()
     */
    function admin_print_styles() {
        wp_enqueue_style( "{$this->namespace}-admin" );
    }
    
    /**
     * Hook into register_deactivation_hook action
     * 
     * Put code here that needs to happen when your plugin is deactivated
     */
    static function deactivate() {
        // Do deactivation actions
		//delete the option for script
		  delete_option('wpptabs_table_themes');     //add table theme   
      
    		}
    
    /**
     * Retrieve the stored plugin option or the default if no user specified value is defined
     * 
     * @param string $option_name The name of the TrialAccount option you wish to retrieve
     * 
     * @uses get_option()
     * 
     * @return mixed Returns the option value or false(boolean) if the option is not found
     */
    function get_option( $option_name ) {
        // Load option values if they haven't been loaded already
        if( !isset( $this->options ) || empty( $this->options ) ) {
            $this->options = get_option( $this->option_name, $this->defaults );
        }
        
        if( isset( $this->options[$option_name] ) ) {
            return $this->options[$option_name];    // Return user's specified option value
        } elseif( isset( $this->defaults[$option_name] ) ) {
            return $this->defaults[$option_name];   // Return default option value
        }
        return false;
    }
    
    /**
     * Initialization function to hook into the WordPress init action
     * 
     * Instantiates the class on a global variable and sets the class, actions
     * etc. up for use.
     */
    static function instance() {
        global $WPPricingTables;
        
        // Only instantiate the Class if it hasn't been already
        if( !isset( $WPPricingTables ) ) $WPPricingTables = new WPPricingTables();
    }
	
	/**
	 * Hook into plugin_action_links filter
	 * 
	 * Adds a "Settings" link next to the "Deactivate" link in the plugin listing page
	 * when the plugin is active.
	 * 
	 * @param object $links An array of the links to show, this will be the modified variable
	 * @param string $file The name of the file being processed in the filter
	 */
    /**
     * Route the user based off of environment conditions
     * 
     * This function will handling routing of form submissions to the appropriate
     * form processor.
     * 
     * @uses WPPricingTables::_admin_options_update()
     */
    function route() {
        $uri = $_SERVER['REQUEST_URI'];
        $protocol = isset( $_SERVER['HTTPS'] ) ? 'https' : 'http';
        $hostname = $_SERVER['HTTP_HOST'];
        $url = "{$protocol}://{$hostname}{$uri}";
        $is_post = (bool) ( strtoupper( $_SERVER['REQUEST_METHOD'] ) == "POST" );
        
        // Check if a nonce was passed in the request
        if( isset( $_REQUEST['_wpnonce'] ) ) {
            $nonce = $_REQUEST['_wpnonce'];
            
            // Handle POST requests
            if( $is_post ) {
                if( wp_verify_nonce( $nonce, "{$this->namespace}-update-options" ) ) {
                    $this->_admin_options_update();
                }
            } 
            // Handle GET requests
            else {
                
            }
        }
    }
    
    /**
     * Register scripts used by this plugin for enqueuing elsewhere
     * 
     * @uses wp_register_script()
     */
    function wp_register_scripts() {
        // Admin JavaScript
        //wp_register_script('wpptabs-table-modifier', WPPTABS_URLPATH . '/js/table_modifier.js', 'null', $this->version, 'false');
    }
    
    /**
     * Register styles used by this plugin for enqueuing elsewhere
     * 
     * @uses wp_register_style()
     */
    function wp_register_styles() {
        // Admin Stylesheet
        wp_register_style( "{$this->namespace}-admin", WPPTABS_URLPATH . "/css/admin.css", array(), $this->version, 'screen' );
    }
}
if( !isset( $WPPricingTables ) ) {
	WPPricingTables::instance();
}

register_activation_hook( __FILE__, array( 'WPPricingTables', 'activate' ) );
register_deactivation_hook( __FILE__, array( 'WPPricingTables', 'deactivate' ) );


